# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: index/faults/rpc/rpc.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='index/faults/rpc/rpc.proto',
  package='index.faults.rpc',
  syntax='proto3',
  serialized_options=b'Z/github.com/textileio/powergate/index/faults/rpc',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1aindex/faults/rpc/rpc.proto\x12\x10index.faults.rpc\"\x98\x01\n\x05Index\x12\x11\n\ttipsetkey\x18\x01 \x01(\t\x12\x33\n\x06miners\x18\x02 \x03(\x0b\x32#.index.faults.rpc.Index.MinersEntry\x1aG\n\x0bMinersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\'\n\x05value\x18\x02 \x01(\x0b\x32\x18.index.faults.rpc.Faults:\x02\x38\x01\"\x18\n\x06\x46\x61ults\x12\x0e\n\x06\x65pochs\x18\x01 \x03(\x03\"\x0c\n\nGetRequest\"5\n\x0bGetResponse\x12&\n\x05index\x18\x01 \x01(\x0b\x32\x17.index.faults.rpc.Index2R\n\nRPCService\x12\x44\n\x03Get\x12\x1c.index.faults.rpc.GetRequest\x1a\x1d.index.faults.rpc.GetResponse\"\x00\x42\x31Z/github.com/textileio/powergate/index/faults/rpcb\x06proto3'
)




_INDEX_MINERSENTRY = _descriptor.Descriptor(
  name='MinersEntry',
  full_name='index.faults.rpc.Index.MinersEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='index.faults.rpc.Index.MinersEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='index.faults.rpc.Index.MinersEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=130,
  serialized_end=201,
)

_INDEX = _descriptor.Descriptor(
  name='Index',
  full_name='index.faults.rpc.Index',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tipsetkey', full_name='index.faults.rpc.Index.tipsetkey', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='miners', full_name='index.faults.rpc.Index.miners', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_INDEX_MINERSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=49,
  serialized_end=201,
)


_FAULTS = _descriptor.Descriptor(
  name='Faults',
  full_name='index.faults.rpc.Faults',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='epochs', full_name='index.faults.rpc.Faults.epochs', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=203,
  serialized_end=227,
)


_GETREQUEST = _descriptor.Descriptor(
  name='GetRequest',
  full_name='index.faults.rpc.GetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=229,
  serialized_end=241,
)


_GETRESPONSE = _descriptor.Descriptor(
  name='GetResponse',
  full_name='index.faults.rpc.GetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='index.faults.rpc.GetResponse.index', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=243,
  serialized_end=296,
)

_INDEX_MINERSENTRY.fields_by_name['value'].message_type = _FAULTS
_INDEX_MINERSENTRY.containing_type = _INDEX
_INDEX.fields_by_name['miners'].message_type = _INDEX_MINERSENTRY
_GETRESPONSE.fields_by_name['index'].message_type = _INDEX
DESCRIPTOR.message_types_by_name['Index'] = _INDEX
DESCRIPTOR.message_types_by_name['Faults'] = _FAULTS
DESCRIPTOR.message_types_by_name['GetRequest'] = _GETREQUEST
DESCRIPTOR.message_types_by_name['GetResponse'] = _GETRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Index = _reflection.GeneratedProtocolMessageType('Index', (_message.Message,), {

  'MinersEntry' : _reflection.GeneratedProtocolMessageType('MinersEntry', (_message.Message,), {
    'DESCRIPTOR' : _INDEX_MINERSENTRY,
    '__module__' : 'index.faults.rpc.rpc_pb2'
    # @@protoc_insertion_point(class_scope:index.faults.rpc.Index.MinersEntry)
    })
  ,
  'DESCRIPTOR' : _INDEX,
  '__module__' : 'index.faults.rpc.rpc_pb2'
  # @@protoc_insertion_point(class_scope:index.faults.rpc.Index)
  })
_sym_db.RegisterMessage(Index)
_sym_db.RegisterMessage(Index.MinersEntry)

Faults = _reflection.GeneratedProtocolMessageType('Faults', (_message.Message,), {
  'DESCRIPTOR' : _FAULTS,
  '__module__' : 'index.faults.rpc.rpc_pb2'
  # @@protoc_insertion_point(class_scope:index.faults.rpc.Faults)
  })
_sym_db.RegisterMessage(Faults)

GetRequest = _reflection.GeneratedProtocolMessageType('GetRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETREQUEST,
  '__module__' : 'index.faults.rpc.rpc_pb2'
  # @@protoc_insertion_point(class_scope:index.faults.rpc.GetRequest)
  })
_sym_db.RegisterMessage(GetRequest)

GetResponse = _reflection.GeneratedProtocolMessageType('GetResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETRESPONSE,
  '__module__' : 'index.faults.rpc.rpc_pb2'
  # @@protoc_insertion_point(class_scope:index.faults.rpc.GetResponse)
  })
_sym_db.RegisterMessage(GetResponse)


DESCRIPTOR._options = None
_INDEX_MINERSENTRY._options = None

_RPCSERVICE = _descriptor.ServiceDescriptor(
  name='RPCService',
  full_name='index.faults.rpc.RPCService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=298,
  serialized_end=380,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='index.faults.rpc.RPCService.Get',
    index=0,
    containing_service=None,
    input_type=_GETREQUEST,
    output_type=_GETRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_RPCSERVICE)

DESCRIPTOR.services_by_name['RPCService'] = _RPCSERVICE

# @@protoc_insertion_point(module_scope)
