# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: index/ask/rpc/rpc.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='index/ask/rpc/rpc.proto',
  package='index.ask.rpc',
  syntax='proto3',
  serialized_options=b'Z,github.com/textileio/powergate/index/ask/rpc',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x17index/ask/rpc/rpc.proto\x12\rindex.ask.rpc\"M\n\x05Query\x12\x11\n\tmax_price\x18\x01 \x01(\x04\x12\x12\n\npiece_size\x18\x02 \x01(\x04\x12\r\n\x05limit\x18\x03 \x01(\x05\x12\x0e\n\x06offset\x18\x04 \x01(\x05\"e\n\nStorageAsk\x12\r\n\x05price\x18\x01 \x01(\x04\x12\x16\n\x0emin_piece_size\x18\x02 \x01(\x04\x12\r\n\x05miner\x18\x03 \x01(\t\x12\x11\n\ttimestamp\x18\x04 \x01(\x03\x12\x0e\n\x06\x65xpiry\x18\x05 \x01(\x03\"\xba\x01\n\x05Index\x12\x14\n\x0clast_updated\x18\x01 \x01(\x03\x12\x1c\n\x14storage_median_price\x18\x02 \x01(\x04\x12\x32\n\x07storage\x18\x03 \x03(\x0b\x32!.index.ask.rpc.Index.StorageEntry\x1aI\n\x0cStorageEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x19.index.ask.rpc.StorageAsk:\x02\x38\x01\"\x0c\n\nGetRequest\"2\n\x0bGetResponse\x12#\n\x05index\x18\x01 \x01(\x0b\x32\x14.index.ask.rpc.Index\"3\n\x0cQueryRequest\x12#\n\x05query\x18\x01 \x01(\x0b\x32\x14.index.ask.rpc.Query\"8\n\rQueryResponse\x12\'\n\x04\x61sks\x18\x01 \x03(\x0b\x32\x19.index.ask.rpc.StorageAsk2\x92\x01\n\nRPCService\x12>\n\x03Get\x12\x19.index.ask.rpc.GetRequest\x1a\x1a.index.ask.rpc.GetResponse\"\x00\x12\x44\n\x05Query\x12\x1b.index.ask.rpc.QueryRequest\x1a\x1c.index.ask.rpc.QueryResponse\"\x00\x42.Z,github.com/textileio/powergate/index/ask/rpcb\x06proto3'
)




_QUERY = _descriptor.Descriptor(
  name='Query',
  full_name='index.ask.rpc.Query',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_price', full_name='index.ask.rpc.Query.max_price', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='piece_size', full_name='index.ask.rpc.Query.piece_size', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='index.ask.rpc.Query.limit', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='index.ask.rpc.Query.offset', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=42,
  serialized_end=119,
)


_STORAGEASK = _descriptor.Descriptor(
  name='StorageAsk',
  full_name='index.ask.rpc.StorageAsk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='price', full_name='index.ask.rpc.StorageAsk.price', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_piece_size', full_name='index.ask.rpc.StorageAsk.min_piece_size', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='miner', full_name='index.ask.rpc.StorageAsk.miner', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='index.ask.rpc.StorageAsk.timestamp', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiry', full_name='index.ask.rpc.StorageAsk.expiry', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=121,
  serialized_end=222,
)


_INDEX_STORAGEENTRY = _descriptor.Descriptor(
  name='StorageEntry',
  full_name='index.ask.rpc.Index.StorageEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='index.ask.rpc.Index.StorageEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='index.ask.rpc.Index.StorageEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=338,
  serialized_end=411,
)

_INDEX = _descriptor.Descriptor(
  name='Index',
  full_name='index.ask.rpc.Index',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='last_updated', full_name='index.ask.rpc.Index.last_updated', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storage_median_price', full_name='index.ask.rpc.Index.storage_median_price', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storage', full_name='index.ask.rpc.Index.storage', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_INDEX_STORAGEENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=225,
  serialized_end=411,
)


_GETREQUEST = _descriptor.Descriptor(
  name='GetRequest',
  full_name='index.ask.rpc.GetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=413,
  serialized_end=425,
)


_GETRESPONSE = _descriptor.Descriptor(
  name='GetResponse',
  full_name='index.ask.rpc.GetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='index.ask.rpc.GetResponse.index', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=427,
  serialized_end=477,
)


_QUERYREQUEST = _descriptor.Descriptor(
  name='QueryRequest',
  full_name='index.ask.rpc.QueryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='index.ask.rpc.QueryRequest.query', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=479,
  serialized_end=530,
)


_QUERYRESPONSE = _descriptor.Descriptor(
  name='QueryResponse',
  full_name='index.ask.rpc.QueryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='asks', full_name='index.ask.rpc.QueryResponse.asks', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=532,
  serialized_end=588,
)

_INDEX_STORAGEENTRY.fields_by_name['value'].message_type = _STORAGEASK
_INDEX_STORAGEENTRY.containing_type = _INDEX
_INDEX.fields_by_name['storage'].message_type = _INDEX_STORAGEENTRY
_GETRESPONSE.fields_by_name['index'].message_type = _INDEX
_QUERYREQUEST.fields_by_name['query'].message_type = _QUERY
_QUERYRESPONSE.fields_by_name['asks'].message_type = _STORAGEASK
DESCRIPTOR.message_types_by_name['Query'] = _QUERY
DESCRIPTOR.message_types_by_name['StorageAsk'] = _STORAGEASK
DESCRIPTOR.message_types_by_name['Index'] = _INDEX
DESCRIPTOR.message_types_by_name['GetRequest'] = _GETREQUEST
DESCRIPTOR.message_types_by_name['GetResponse'] = _GETRESPONSE
DESCRIPTOR.message_types_by_name['QueryRequest'] = _QUERYREQUEST
DESCRIPTOR.message_types_by_name['QueryResponse'] = _QUERYRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Query = _reflection.GeneratedProtocolMessageType('Query', (_message.Message,), {
  'DESCRIPTOR' : _QUERY,
  '__module__' : 'index.ask.rpc.rpc_pb2'
  # @@protoc_insertion_point(class_scope:index.ask.rpc.Query)
  })
_sym_db.RegisterMessage(Query)

StorageAsk = _reflection.GeneratedProtocolMessageType('StorageAsk', (_message.Message,), {
  'DESCRIPTOR' : _STORAGEASK,
  '__module__' : 'index.ask.rpc.rpc_pb2'
  # @@protoc_insertion_point(class_scope:index.ask.rpc.StorageAsk)
  })
_sym_db.RegisterMessage(StorageAsk)

Index = _reflection.GeneratedProtocolMessageType('Index', (_message.Message,), {

  'StorageEntry' : _reflection.GeneratedProtocolMessageType('StorageEntry', (_message.Message,), {
    'DESCRIPTOR' : _INDEX_STORAGEENTRY,
    '__module__' : 'index.ask.rpc.rpc_pb2'
    # @@protoc_insertion_point(class_scope:index.ask.rpc.Index.StorageEntry)
    })
  ,
  'DESCRIPTOR' : _INDEX,
  '__module__' : 'index.ask.rpc.rpc_pb2'
  # @@protoc_insertion_point(class_scope:index.ask.rpc.Index)
  })
_sym_db.RegisterMessage(Index)
_sym_db.RegisterMessage(Index.StorageEntry)

GetRequest = _reflection.GeneratedProtocolMessageType('GetRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETREQUEST,
  '__module__' : 'index.ask.rpc.rpc_pb2'
  # @@protoc_insertion_point(class_scope:index.ask.rpc.GetRequest)
  })
_sym_db.RegisterMessage(GetRequest)

GetResponse = _reflection.GeneratedProtocolMessageType('GetResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETRESPONSE,
  '__module__' : 'index.ask.rpc.rpc_pb2'
  # @@protoc_insertion_point(class_scope:index.ask.rpc.GetResponse)
  })
_sym_db.RegisterMessage(GetResponse)

QueryRequest = _reflection.GeneratedProtocolMessageType('QueryRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYREQUEST,
  '__module__' : 'index.ask.rpc.rpc_pb2'
  # @@protoc_insertion_point(class_scope:index.ask.rpc.QueryRequest)
  })
_sym_db.RegisterMessage(QueryRequest)

QueryResponse = _reflection.GeneratedProtocolMessageType('QueryResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYRESPONSE,
  '__module__' : 'index.ask.rpc.rpc_pb2'
  # @@protoc_insertion_point(class_scope:index.ask.rpc.QueryResponse)
  })
_sym_db.RegisterMessage(QueryResponse)


DESCRIPTOR._options = None
_INDEX_STORAGEENTRY._options = None

_RPCSERVICE = _descriptor.ServiceDescriptor(
  name='RPCService',
  full_name='index.ask.rpc.RPCService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=591,
  serialized_end=737,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='index.ask.rpc.RPCService.Get',
    index=0,
    containing_service=None,
    input_type=_GETREQUEST,
    output_type=_GETRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Query',
    full_name='index.ask.rpc.RPCService.Query',
    index=1,
    containing_service=None,
    input_type=_QUERYREQUEST,
    output_type=_QUERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_RPCSERVICE)

DESCRIPTOR.services_by_name['RPCService'] = _RPCSERVICE

# @@protoc_insertion_point(module_scope)
